==> pfqueue-0.3.4.tar.gz: pfqueue-0.3.4/ncgui.c <==

/*
 * Funzioni di interfaccia ncurses5
 */

#include "ncgui.h"
#include "pfregex.h"
#include <string.h>

const char VERT  = '|';
const char ORIZ  = '-';
const char INCR  = '+';
const char DVERT = '#';
const char DORIZ = '=';
const char DINCR = '*';

#define VID_BUF 20

extern int TAGGED;
extern int delay_time;

void wnd_clear ( WINDOW* wnd, const char* title ) {
	wclear ( wnd );
	wnd_border ( wnd );
	wattron ( wnd, A_BOLD );
	mvwaddstr ( wnd, 0,2, title );
	wattroff ( wnd, A_BOLD );
}

void wnd_border ( WINDOW* wnd ) {
	wborder ( wnd, VERT, VERT, ORIZ, ORIZ, INCR, INCR, INCR, INCR );
}

void wnd_prompt ( WINDOW* wnd, int y, int x, char** buf, int buflen ) {
	if ( strlen(regexps) )
		strncpy ( *buf, regexps, strlen(regexps) );
	else
		memset ( *buf, 0, buflen );
	mvwaddstr ( wnd, y, x, *buf );
	mvwgetstr ( wnd, y, x, *buf ); 
}

int wnd_confirm ( const char *action ) {
	int c, ret;

	WINDOW *w = newwin ( 5, 50, (LINES-5)/2, (COLS-50)/2 );
	wnd_border ( w );
	
	nocbreak();
	cbreak();
	
	if ( !TAGGED )
		mvwprintw ( w, 2, 2, "Do you really want to %s this message?", action );
	else
		mvwprintw ( w, 2, 2, "Do you really want to %s tagged messages?", action );
	wrefresh ( w );
	
	c = wgetch ( w );
	ret =  ( c=='y' || c=='Y' ? 1 : 0 );

	delwin ( w );

	halfdelay ( delay_time*10 );
	return ret;
}

void wnd_getregexp () {

	WINDOW *w = newwin ( 5, 60, (LINES-5)/2, (COLS-60)/2 );
	wnd_border ( w );

	echo();
	nocbreak();
	cbreak();

	mvwaddstr ( w, 1, 2, "Insert POSIX regular expression to search:" );
	wrefresh ( w );

	wnd_prompt ( w, 3, 2, &regexps, sizeof(regexps) );

	delwin ( w );
	halfdelay ( delay_time*10 );
	return;
}

==> pfqueue-0.3.8.tar.gz: pfqueue-0.3.8/ncgui.c <==

/*
 * Funzioni di interfaccia ncurses5
 */

#include "ncgui.h"
#include "pfregex.h"
#include <string.h>
#include <stdlib.h>

const char VERT  = '|';
const char ORIZ  = '-';
const char INCR  = '+';
const char DVERT = '#';
const char DORIZ = '=';
const char DINCR = '*';

#define VID_BUF 20

extern int WRK_TAGGED;
extern int delay_time;

void wnd_clear ( WINDOW* wnd, const char* title ) {
	wclear ( wnd );
	wnd_border ( wnd );
	wattron ( wnd, A_BOLD );
	mvwaddstr ( wnd, 0,2, title );
	wattroff ( wnd, A_BOLD );
}

void wnd_border ( WINDOW* wnd ) {
	wborder ( wnd, VERT, VERT, ORIZ, ORIZ, INCR, INCR, INCR, INCR );
}

void wnd_prompt ( WINDOW* wnd, int y, int x, char** buf, int buflen ) {
	if ( strlen(regexps) )
		strncpy ( *buf, regexps, strlen(regexps) );
	else
		memset ( *buf, 0, buflen );
	mvwaddstr ( wnd, y, x, *buf );
	mvwgetnstr ( wnd, y, x, *buf, buflen ); 
}

int wnd_confirm ( const char *action ) {
	int c, ret;

	WINDOW *w = newwin ( 5, 50, (LINES-5)/2, (COLS-50)/2 );
	wnd_border ( w );
	
	nocbreak();
	cbreak();
	
	if ( !WRK_TAGGED )
		mvwprintw ( w, 2, 2, "Do you really want to %s this message?", action );
	else
		mvwprintw ( w, 2, 2, "Do you really want to %s tagged messages?", action );
	wrefresh ( w );
	
	c = wgetch ( w );
	ret =  ( c=='y' || c=='Y' ? 1 : 0 );

	delwin ( w );

	halfdelay ( delay_time*10 );
	return ret;
}

void wnd_getregexp () {

	char *tmp;
	
	WINDOW *w = newwin ( 5, 60, (LINES-5)/2, (COLS-60)/2 );
	wnd_border ( w );

	echo();
	nocbreak();
	cbreak();

	mvwaddstr ( w, 1, 2, "Insert POSIX regular expression to search:" );
	wrefresh ( w );

	wnd_prompt ( w, 3, 2, &regexps, REGEXP_LEN );

	delwin ( w );
	halfdelay ( delay_time*10 );
	noecho();

	search_mode = SM_ALL;
	if ( !strncmp( regexps, "f:", 2 ) )
		search_mode = SM_FROM;
	if ( !strncmp( regexps, "t:", 2 ) )
		search_mode = SM_TO;
	if ( !strncmp( regexps, "e:", 2 ) )
		search_mode = SM_TO | SM_FROM;
	if ( !strncmp( regexps, "s:", 2 ) )
		search_mode = SM_SUBJ;

	if ( search_mode != ( SM_ALL ) ) {
		tmp = (char*) malloc ( REGEXP_LEN );
		strncpy ( tmp, regexps+2, REGEXP_LEN );
		strncpy ( regexps, tmp, REGEXP_LEN );
		free ( tmp );
	}
		
	return;
}
